referrerpolicy=no-referrer-when-downgrade

ExtrinsicWeightReclaimed

Type Alias ExtrinsicWeightReclaimed 

pub type ExtrinsicWeightReclaimed<T>
where T: Config,
= StorageValue<_GeneratedPrefixForStorageExtrinsicWeightReclaimed<T>, Weight, ValueQuery>;
The weight reclaimed for the extrinsic.

This information is available until the end of the extrinsic execution. More precisely this information is removed in note_applied_extrinsic.

Logic doing some post dispatch weight reduction must update this storage to avoid duplicate reduction.

Storage type is [StorageValue] with value type Weight.

Aliased Type

pub struct ExtrinsicWeightReclaimed<T>(/* private fields */)
where
    T: Config;